from networkx.classes.digraph import DiGraph
from networkx.classes.graph import Graph, _Node
from networkx.utils.backends import _dispatchable

@_dispatchable
def is_arborescence(G: Graph[_Node]): ...
@_dispatchable
def is_branching(G: DiGraph[_Node]): ...
@_dispatchable
def is_forest(G: Graph[_Node]): ...
@_dispatchable
def is_tree(G: Graph[_Node]): ...
