from _typeshed import Incomplete
from collections.abc import Iterable

from networkx.utils.backends import _dispatchable

@_dispatchable
def is_graphical(sequence: Iterable[Incomplete], method="eg"): ...
@_dispatchable
def is_valid_degree_sequence_havel_hakimi(deg_sequence: Iterable[Incomplete]): ...
@_dispatchable
def is_valid_degree_sequence_erdos_gallai(deg_sequence: Iterable[Incomplete]): ...
@_dispatchable
def is_multigraphical(sequence: Iterable[Incomplete]): ...
@_dispatchable
def is_pseudographical(sequence: Iterable[Incomplete]): ...
@_dispatchable
def is_digraphical(in_sequence: Iterable[Incomplete], out_sequence: Iterable[Incomplete]): ...
