from networkx.classes.graph import Graph, _Node
from networkx.utils.backends import _dispatchable

@_dispatchable
def is_regular(G: Graph[_Node]): ...
@_dispatchable
def is_k_regular(G: Graph[_Node], k): ...
@_dispatchable
def k_factor(G: Graph[_Node], k, matching_weight: str | None = "weight"): ...
